==> ejc-production-api-3.0.0-20220615.152355-161-sources.jar: com/ejianc/business/production/task/hystrix/ProductionTaskHystrix.java <==
package com.ejianc.business.production.task.hystrix;

import com.ejianc.business.production.task.api.ProductionTaskApi;
import com.ejianc.business.production.task.vo.DelivergoodsVO;
import com.ejianc.business.production.task.vo.ProductionTaskApiVo;

import com.ejianc.business.production.task.vo.TaskDistributeCarVO;
import com.ejianc.business.production.task.vo.TasktransportVO;
import com.ejianc.framework.core.exception.BusinessException;
import org.springframework.stereotype.Component;

import com.ejianc.framework.core.response.CommonResponse;

import java.util.List;

/**
 * 生成销售单的hystrix
 *
 * @author liyongjia
 *
 */
@Component
public class ProductionTaskHystrix implements ProductionTaskApi {


    @Override
    public CommonResponse<ProductionTaskApiVo> getproductiontask(String taskId, String carCode) {
        throw new BusinessException("网络问题， 保存失败。");
    }

    @Override
    public CommonResponse<DelivergoodsVO> getDeliver(String carCode, String orgId, String transportTime) {
        throw new BusinessException("网络问题， 保存失败。");
    }

    @Override
    public CommonResponse updateTransportState(Long transportId, Integer status) {
        throw new BusinessException("网络问题， 保存失败。");
    }

    @Override
    public CommonResponse updateTransport(TasktransportVO tasktransportVO) {
        throw new BusinessException("网络问题， 保存失败。");
    }

    @Override
    public CommonResponse<List<TaskDistributeCarVO>> queryShipment(Long taskId) {
        throw new BusinessException("网络问题， 查询失败。");
    }
}

==> ejc-production-api-3.0.0-20220617.045002-164-sources.jar: com/ejianc/business/production/task/hystrix/ProductionTaskHystrix.java <==
package com.ejianc.business.production.task.hystrix;

import com.ejianc.business.production.task.api.ProductionTaskApi;
import com.ejianc.business.production.task.vo.DelivergoodsVO;
import com.ejianc.business.production.task.vo.ProductionTaskApiVo;

import com.ejianc.business.production.task.vo.TaskDistributeCarVO;
import com.ejianc.business.production.task.vo.TasktransportVO;
import com.ejianc.framework.core.exception.BusinessException;
import org.springframework.stereotype.Component;

import com.ejianc.framework.core.response.CommonResponse;

import java.util.List;
import java.util.Map;

/**
 * 生成销售单的hystrix
 *
 * @author liyongjia
 *
 */
@Component
public class ProductionTaskHystrix implements ProductionTaskApi {


    @Override
    public CommonResponse<ProductionTaskApiVo> getproductiontask(String taskId, String carCode) {
        throw new BusinessException("网络问题， 保存失败。");
    }

    @Override
    public CommonResponse<DelivergoodsVO> getDeliver(String carCode, String orgId, String transportTime) {
        throw new BusinessException("网络问题， 保存失败。");
    }

    @Override
    public CommonResponse updateTransportState(Long transportId, Integer status) {
        throw new BusinessException("网络问题， 保存失败。");
    }

    @Override
    public CommonResponse updateTransport(TasktransportVO tasktransportVO) {
        throw new BusinessException("网络问题， 保存失败。");
    }

    @Override
    public CommonResponse<Map<String, Object>> queryShipment(Long taskId) {
        throw new BusinessException("网络问题， 查询失败。");
    }
}
